@@ -51,7 +51,7 @@ def stylesheets_output(context):
 def scripts_output(context):
 	request = context['request']
 	if hasattr(request, 'script_config'):
-		request.scripts.append("""(function(){if (window.root === undefined) window.root = {}; if (window.root.config === undefined) window.root.config = {}; var additionalConfig = {config}; for (k in additionalConfig) window.root.config[k] = additionalConfig[k];})();""".format(config=json.dumps(request.script_config)))
+		request.scripts.append("""(function(){if (window.root === undefined) window.root = {}; if (window.root.config === undefined) window.root.config = {}; var additionalConfig = %s; for (k in additionalConfig) window.root.config[k] = additionalConfig[k];})();""" % json.dumps(request.script_config))
 	return mark_safe("".join([
 		"<script type='text/javascript'>%s</script>" % s if isinstance(s, basestring) else "<script type='text/javascript' src='%s'></script>" % static(s['link'])
 	    for s in request.scripts
